# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/b/realestate/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/b/realestate/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "B\\Realestate\\": "packages/b/realestate/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        B\Realestate\Providers\RealestateServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Realestate'  => B\Realestate\Facades\Realestate::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=B\\RealestateTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="B\Realestate\Providers\RealestateServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="B\Realestate\Providers\RealestateServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="B\Realestate\Providers\RealestateServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/realestate/{modulename}

**User**

    http://path-to-route-folder/user/realestate/{modulename}

**Public**

    http://path-to-route-folder/realestates


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/realestate/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/realestate/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/realestate/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/realestate/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/realestate/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/realestate/{modulename}/{slug}
    METHOD: GET